//===========================================================================
// Released under Anonymity
// Feel free to embrace and extend this code!
// 11/16/02
// 
// ResourceExtractorListener.h
// 
// Declaration of an interface which when implemented by a class allows 
// instance of that class to connect to and receive messages from a 
// esourceExtractor object.
//===========================================================================

//===========================================================================
//include guard
//===========================================================================
#ifndef __RESOURCE_EXTRACTOR_LISTENER_H_INCLUDED
#define __RESOURCE_EXTRACTOR_LISTENER_H_INCLUDED

//===========================================================================
// Delcaration of interface: IResourceExtractorListener
//
// An interface for hooking into ResourceExtractor events.  
// Resource Extractor only holds instance of this interface at at time
// and you can only connect implementors of this interface to 
// ResourceExtractor instances at the time you construct said instances.
//===========================================================================
struct IResourceExtractorListener
{
	// onByte gets called for every byte processed.  inline for performance reasons.
	virtual void onByte(int byteValue,size_t byteNum)=0;
	// Is called when the resource extractor opens a file
	virtual void onFileOpen(char* szFilePath,size_t position)=0;
	// This is called when the resource extractor closes a file
	virtual void onFileClose(char* szFilePath, size_t position, size_t numBytes, size_t numTrailingBytes)=0;
	// This is called once when the main data file is opened
	virtual void onMainFileOpen(char* szMainFileName,size_t totalBytes)=0;
	// Called once when the main data file is closed. 
	virtual void onMainFileClose(char* szFileName)=0;
	// Called when the listener is disconnected prematurely
	virtual void disconnect()=0;
};
#endif