//===========================================================================
// Released under Anonymity
// Feel free to embrace and extend this code!
// 11/16/02
// 
// ResourceExtractorState_ExtractingFile.cpp
// 
// Implementation of a resource extractor state that extracts bytes from
// the main file to a resource file until the end of the resource is found
//===========================================================================

//===========================================================================
// Included Files
//===========================================================================
#include "projectpch.h"
#include "ResourceExtractor.h"

//===========================================================================
// Definition of Constructor: CResourceExtractor::ExtractingFile::
//                ExtractingFile(CResourceExtractor* pOwningExtractor)
//
// This constructor simply defers to the super class constructor
//===========================================================================
CResourceExtractor::ExtractingFile::ExtractingFile(CResourceExtractor* pOwningExtractor)
:State(pOwningExtractor)
{
}

//===========================================================================
// Definition of Method: CResourceExtractor::ExtractingFile::beginState()
//
// This beginState method just resets the index into the end-of-resource 
// comparison array back to zero
//===========================================================================
void CResourceExtractor::ExtractingFile::beginState()
{
	m_compareidx=0;
}

//===========================================================================
// Definition of Method: CResourceExtractor::ExtractingFile::
//                                                        processByte(int c)
//
// checks the byte  against the current index of the end-of-resource 
// comparison array. if the byte completes the comparison, the array
// is written to the resource file and state is changed to scan for trailing
// bytes (closing file if trailing byte scanning is turned off)
// if the byte does not match the comparison array at the current index
// then the bytes that partially matched the array previous to this
// (if any) are written to the resource file, then finally the current byte 
// is written.
//===========================================================================
void CResourceExtractor::ExtractingFile::processByte(int c)
{
	if (c == m_pOwner->m_szEndCompareString[m_compareidx])
	{
		++m_compareidx;
		if (m_compareidx >= m_pOwner->m_endcomparelen)
		{
			for (int i=0;i<m_compareidx;++i)
			{
				++m_pOwner->m_CurrFileSize;
				fputc(m_pOwner->m_szEndCompareString[i],m_pOwner->m_poutfile);
			}

			m_compareidx=0;
			if (m_pOwner->m_bDoTrailingBytes)
			{
				m_pOwner->GotoState(new ScanningTrailingBytes(m_pOwner));
				return;
			}
			else
			{
				m_pOwner->GotoState(new ClosingFile(m_pOwner));
				return;
			}
		}
	}
	else
	{
		if (m_compareidx > 0)
		{
			for (int i=0;i<m_compareidx;++i)
			{
				++m_pOwner->m_CurrFileSize;
				fputc(m_pOwner->m_szEndCompareString[i],m_pOwner->m_poutfile);
			}
		}
		++m_pOwner->m_CurrFileSize;
		fputc(c,m_pOwner->m_poutfile);

		m_compareidx=0;
	}
}

