//===========================================================================
// Released under Anonymity
// Feel free to embrace and extend this code!
// 11/16/02
// 
// ResourceExtractorState_ScanningTrailingBytes.cpp
// 
// Implementation of a state in the resource extractor in which
// trailing bytes of a resource file are being scanned for an end
//===========================================================================

//===========================================================================
// Included Files
//===========================================================================
#include "projectpch.h"
#include "ResourceExtractor.h"

//===========================================================================
// Definition of Constructor: CResourceExtractor::ScanningTrailingBytes::
//                ScanningTrailingBytes(CResourceExtractor* pOwningExtractor)       
//
// This constructor simply defers to the super class constructor
//===========================================================================
CResourceExtractor::ScanningTrailingBytes::ScanningTrailingBytes(CResourceExtractor* pOwningExtractor)
:State(pOwningExtractor)
{
}

//===========================================================================
// Definition of Method: CResourceExtractor::ScanningTrailingBytes::
//                                                         processByte(int c)
//
// This state's processByte extracts bytes until it finds one that does 
// not match the given trailing byte value.  At that point it pushes that
// byte back onto the input queue and changes state to ClosingFile
//===========================================================================
void CResourceExtractor::ScanningTrailingBytes::processByte(int c)
{
	if (c==m_pOwner->m_cTrailingByte)
	{
		++m_pOwner->m_numTrailingBytes;
		++m_pOwner->m_CurrFileSize;
		fputc(c,m_pOwner->m_poutfile);
	}
	else
	{
		m_pOwner->backTrack(1);
		m_pOwner->GotoState(new ClosingFile(m_pOwner));
        return;
	}
}
