//===========================================================================
// Released under Anonymity
// Feel free to embrace and extend this code!
// 11/16/02
// 
// ResourceExtractorState_SearchingForStart.cpp
// 
// Implementation of a resource extractor state that processes bytes
// looking for the start of a resource file
//===========================================================================

//===========================================================================
// Included Files
//===========================================================================
#include "projectpch.h"
#include "ResourceExtractor.h"

//===========================================================================
// Definition of Constructor: CResourceExtractor::SearchingForStart::
//                    SearchingForStart(CResourceExtractor* pOwningExtractor)       
//
// This constructor simply defers to the super class constructor
//===========================================================================
CResourceExtractor::SearchingForStart::SearchingForStart(CResourceExtractor* pOwningExtractor)
:State(pOwningExtractor)
{
}

//===========================================================================
// Definition of Method: CResourceExtractor::SearchingForStart::beginState()
//
// This beginState method just resets the index into the start-of-resource 
// comparison array to zero
//===========================================================================
void CResourceExtractor::SearchingForStart::beginState()
{
	m_compareidx=0;
}

//===========================================================================
// Definition of Method: CResourceExtractor::SearchingForStart::processByte
//                                                                    (int c)
//
// This state's processByte method compares bytes to the current index in
// in the start-of-resource comparison array. If the byte completes a match
// of the whole array, then the extractor is moved to the CreatingFile state.
// if it doesn't match, the array matching is reset to the first index.
// if it does match but doesn't complete the array, then the index is
// incremented.
//===========================================================================
void CResourceExtractor::SearchingForStart::processByte(int c)
{
	if (c == m_pOwner->m_szStartCompareString[m_compareidx])
	{
		++m_compareidx;
		if (m_compareidx >= m_pOwner->m_startcomparelen)
		{
			m_pOwner->GotoState(new CreatingFile(m_pOwner));
			return;
		}
	}
	else
	{
		m_compareidx=0;
	}
}
